<?php

namespace DigitalPoint\Cloudflare\Template\Callback;

use XF\Template\Templater;

class Cloudflare
{
	public static function getCreateWidgetButton($contents, array $params, Templater $templater): string
	{
		$options = \XF::options();

		if ((empty($options->cloudflareAuth['email']) || empty($options->cloudflareAuth['api_key'])) && empty($options->cloudflareAuth['token']))
		{
			$params['noAuth'] = true;
		}
		else
		{
			$cloudflareRepo = self::getCloudflareRepo();

			try
			{
				$params['widget'] = $cloudflareRepo->getTurnstileWidgetByDomain();

				if ($params['widget'])
				{
					$params['turnstileSiteUrl'] = $cloudflareRepo->getTurnstileSiteUrl($params['widget']['sitekey']);
					$params['turnstileSiteUrlEdit'] = $cloudflareRepo->getTurnstileSiteUrlEdit($params['widget']['sitekey']);
				}
			}
			catch(\Exception $e)
			{
				\XF::logError(strip_tags($e->getMessage()));
			}
		}
		return $templater->renderTemplate('admin:cloudflare_widget_create_button', $params);
	}

	public static function getStats($contents, array $params, \XF\Template\Templater $templater)
	{
		if (\XF::options()->cfTokenId && \XF::visitor()->hasAdminPermission('viewStatistics'))
		{
			/** @var \DigitalPoint\Cloudflare\Repository\Cloudflare $cloudflareRepo */
			$cloudflareRepo = \XF::repository('DigitalPoint\Cloudflare:Cloudflare');
			try {
				$params['dash_base'] = $cloudflareRepo->getDashBase();
				return $templater->renderTemplate('admin:cloudflare_stats_block', $params);
			} catch (\Exception $e) {}
		}

		return '';
	}

	public static function getHelpBlurb($contents, array $params, Templater $templater): string
	{
		$md5 = md5(\XF::options()->boardUrl);
		$params['stickyNumber'] = hexdec(substr($md5, 0, 2)) % 4;
		$params['url'] = (hexdec(substr($md5, 2, 2)) % 3) ? 'https://appforcf.com' : 'https://appforcf.com/items/app-for-cloudflare%C2%AE-pro.1/';
		return $templater->renderTemplate('public:cloudflare_help_blurb', $params);
	}


	/*
	 * This is a hacky workaround for addons being disabled when templates are being compiled during the upgrade process.
	 * See: https://xenforo.com/community/threads/upgrading-to-2-2-14-reset-asset-folder.219059/
	 */
	public static function getAddonActionMacros($matches)
	{
		if (\XF::app() instanceof \XF\Install\App)
		{
			\DigitalPoint\Cloudflare\Listener\AppSetup::run(\XF::app());
		}
		return $matches[0];
	}


	/**
	 * @return \DigitalPoint\Cloudflare\Repository\Cloudflare
	 */
	static function getCloudflareRepo()
	{
		return \XF::repository('DigitalPoint\Cloudflare:Cloudflare');
	}
}