<?php

namespace DigitalPoint\Cloudflare\XF\Entity;

class Post extends XFCP_Post
{
	protected function _postSave()
	{
		parent::_postSave();
		$this->purgeCloudflareCache();
	}

	protected function _postDelete()
	{
		parent::_postDelete();
		$this->purgeCloudflareCache();
	}

	protected function purgeCloudflareCache()
	{
		if (\XF::options()->cfPageCachingSeconds && \XF::options()->cloudflarePurgeCachePost && $this->thread_id && $this->Thread)
		{
			$perPage = \XF::options()->messagesPerPage;
			$total = $this->Thread->reply_count + 1;

			if ($perPage < 1 || $total < 1)
			{
				return;
			}

			$maxPage = ceil($total / $perPage);

			$router = $this->app()->router('public');
			$route = 'canonical:threads';

			$urls = [$router->buildLink($route, $this->Thread)];

			if ($maxPage > 1)
			{
				$urls[] = $router->buildLink($route, $this->Thread, ['page' => 2]);
			}
			if ($maxPage > 3)
			{
				$urls[] = $router->buildLink($route, $this->Thread, ['page' => $maxPage - 1]);
			}
			if ($maxPage > 2)
			{
				$urls[] = $router->buildLink($route, $this->Thread, ['page' => $maxPage]);
			}

			$jobManager = $this->app()->jobManager();
			$jobManager->enqueue('DigitalPoint\Cloudflare\Job\PurgeCache', ['urls' => $urls]);
		}
	}

}

// ******************** FOR IDE AUTO COMPLETE ********************
if (false)
{
	class XFCP_Post extends \XF\Entity\Post {}
}